"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _propTypes = _interopRequireDefault(require("prop-types"));
var _classnames = _interopRequireDefault(require("classnames"));
var _bind = _interopRequireDefault(require("classnames/bind"));
var _terraThemeContext = _interopRequireDefault(require("terra-theme-context"));
var _terraButton = _interopRequireDefault(require("terra-button"));
var _terraContentContainer = _interopRequireDefault(require("terra-content-container"));
var _reactIntl = require("react-intl");
var _DialogModule = _interopRequireDefault(require("./Dialog.module.scss"));
var _excluded = ["children", "footer", "header", "intl", "onClose"];
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } } return target; }
var cx = _bind.default.bind(_DialogModule.default);
var propTypes = {
  /**
   * The children to be placed within the main content area of the dialog.
   */
  children: _propTypes.default.node,
  /**
   * React node to be placed within the footer area of the dialog.
   * Content exceeding the available space will be hidden.
   */
  footer: _propTypes.default.node.isRequired,
  /**
   * React node to be placed within the header area of the dialog.
   */
  header: _propTypes.default.node.isRequired,
  /**
   * @private
   * intl object programmatically imported through injectIntl from react-intl.
   * */
  intl: _propTypes.default.shape({
    formatMessage: _propTypes.default.func
  }).isRequired,
  /**
   * Callback function for when the close button is clicked. The close button will not display if this is not set.
   * On small viewports a back button will be displayed instead of a close button.
   */
  onClose: _propTypes.default.func
};
var defaultProps = {
  onClose: null,
  children: null
};
var Dialog = function Dialog(_ref) {
  var children = _ref.children,
    footer = _ref.footer,
    header = _ref.header,
    intl = _ref.intl,
    onClose = _ref.onClose,
    customProps = _objectWithoutProperties(_ref, _excluded);
  var theme = _react.default.useContext(_terraThemeContext.default);
  var dialogClassNames = (0, _classnames.default)(cx('dialog', theme.className), customProps.className);
  var closeButton = onClose ? /*#__PURE__*/_react.default.createElement("div", {
    className: cx('dialog-header-close')
  }, /*#__PURE__*/_react.default.createElement(_terraButton.default, {
    variant: "utility",
    text: intl.formatMessage({
      id: 'Terra.dialog.close'
    }),
    onClick: onClose,
    isIconOnly: true,
    icon: /*#__PURE__*/_react.default.createElement("span", {
      className: cx('close-icon')
    })
  })) : null;
  var dialogHeader = /*#__PURE__*/_react.default.createElement("div", {
    className: cx('dialog-header')
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: cx('dialog-header-title')
  }, header), closeButton);
  return /*#__PURE__*/_react.default.createElement("div", _extends({}, customProps, {
    className: dialogClassNames
  }), /*#__PURE__*/_react.default.createElement(_terraContentContainer.default, {
    fill: true,
    header: dialogHeader,
    footer: /*#__PURE__*/_react.default.createElement("div", {
      className: cx('dialog-footer')
    }, footer)
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: cx('dialog-body')
  }, children)));
};
Dialog.propTypes = propTypes;
Dialog.defaultProps = defaultProps;
var _default = exports.default = (0, _reactIntl.injectIntl)(Dialog);